@@ -24,6 +24,28 @@ while ($file = readdir($dp)) {
 }
 closedir($dp);
 
+// Get image files from root
+$files_list_root = Array($this->lang('none')=>"-1");
+$dp_root = opendir($gCms->config['root_path']);
+while ($file_root = readdir($dp_root)) {  
+    if (strpos(substr($file_root, -5),'.gif') !== false) {
+        $files_list_root[$file_root] = $file_root;
+    }
+    if (strpos(substr($file_root, -5),'.png') !== false) {
+        $files_list_root[$file_root] = $file_root;
+    }
+    if (strpos(substr($file_root, -5),'.jpg') !== false) {
+        $files_list_root[$file_root] = $file_root;
+    }
+    if (strpos(substr($file_root, -5),'.jpeg') !== false) {
+        $files_list_root[$file_root] = $file_root;
+    }
+    if (strpos(substr($file_root, -5),'.ico') !== false) {
+        $files_list_root[$file_root] = $file_root;
+    }
+}
+closedir($dp_root);
+
 $dropDown = array();
 $dropDown[$this->Lang('drop_select')] = '-1';
 $dropDown[$this->Lang('drop_yes')] = 'yes';
@@ -35,6 +57,11 @@ $barStyle[$this->Lang('style_default')] = 'default';
 $barStyle[$this->Lang('style_black')] = 'black';
 $barStyle[$this->Lang('style_translucent')] = 'black-translucent';
 
+$robotsDrop = array();
+$robotsDrop[$this->Lang('robots_default')] = '-1';
+$robotsDrop[$this->Lang('robots_1')] = '0';
+$robotsDrop[$this->Lang('robots_2')] = '1';
+$robotsDrop[$this->Lang('robots_3')] = '2';
 
 // CreateFormStart sets up a proper form tag that will cause the submit to
 // return control to this module for processing.
@@ -49,12 +76,19 @@ $smarty->assign('page_title_help',$this->Lang('page_title_help'));
 $smarty->assign('page_smarty_help',$this->Lang('page_smarty_help'));
 $smarty->assign('delimiter_title_help',$this->Lang('delimiter_title_help'));
 $smarty->assign('block_title_help',$this->Lang('block_title_help'));
+$smarty->assign('canonical_block_title_help',$this->Lang('canonical_block_title_help'));
 $smarty->assign('meta_block_title_help',$this->Lang('meta_block_title_help'));
 $smarty->assign('content_var_title_help',$this->Lang('content_var_title_help'));
+$smarty->assign('touchicon_root_title_help',$this->Lang('touchicon_root_title_help'));
 $smarty->assign('touchicon_title_help',$this->Lang('touchicon_title_help'));
 $smarty->assign('ogimage_title_help',$this->Lang('ogimage_title_help'));
+$smarty->assign('ogtype_smarty_title_help',$this->Lang('ogtype_smarty_title_help'));
+$smarty->assign('ogimage_smarty_title_help',$this->Lang('ogimage_smarty_title_help'));
+$smarty->assign('favicon_root_title_help',$this->Lang('favicon_root_title_help'));
 $smarty->assign('favicon_title_help',$this->Lang('favicon_title_help'));
 $smarty->assign('favsize_title_help',$this->Lang('favsize_title_help'));
+$smarty->assign('twittersite_title_help',$this->Lang('twittersite_title_help'));
+$smarty->assign('googleplus_title_help',$this->Lang('googleplus_title_help'));
 
 $smarty->assign('title_page_smarty',$this->Lang('page_smarty'));
 $smarty->assign('input_page_smarty',$this->CreateInputText($id,'page_smarty',$this->GetPreference('page_smarty',''),50,255));
@@ -74,6 +108,9 @@ $smarty->assign('input_content_var_title',$this->CreateInputText($id,'content_va
 $smarty->assign('title_block_title',$this->Lang('block_title'));
 $smarty->assign('input_block_title',$this->CreateInputText($id,'block_title',$this->GetPreference('block_title',''),50,255));
 
+$smarty->assign('title_canonical_block_title',$this->Lang('canonical_block_title'));
+$smarty->assign('input_canonical_block_title',$this->CreateInputText($id,'canonical_block_title',$this->GetPreference('canonical_block_title',''),50,255));
+
 $smarty->assign('title_auto_title',$this->Lang('auto_title'));
 $smarty->assign('input_auto_title', $this->CreateInputCheckbox($id,'auto_title','1', $this->GetPreference('auto_title','1')));
 
@@ -95,6 +132,9 @@ $smarty->assign('input_opengraph_title', $this->CreateInputCheckbox($id,'opengra
 $smarty->assign('title_tweetme_title',$this->Lang('tweetme_title'));
 $smarty->assign('input_tweetme_title', $this->CreateInputCheckbox($id,'tweetme_title','1', $this->GetPreference('tweetme_title','0')));
 
+$smarty->assign('title_touchicon_root_title',$this->Lang('touchicon_root_title'));
+$smarty->assign('input_touchicon_root_title',$this->CreateInputDropdown($id,'touchicon_root_title',$files_list_root,-1,$this->GetPreference('touchicon_root_title','')));
+
 $smarty->assign('title_touchicon_title',$this->Lang('touchicon_title'));
 $smarty->assign('input_touchicon_title',$this->CreateInputDropdown($id,'touchicon_title',$files_list,-1,$this->GetPreference('touchicon_title','')));
 
@@ -125,6 +165,9 @@ $smarty->assign('input_maximum_title',$this->CreateInputText($id,'maximum_title'
 $smarty->assign('title_scalable_title',$this->Lang('scalable_title'));
 $smarty->assign('input_scalable_title',$this->CreateInputDropdown($id,'scalable_title',$dropDown,$this->GetPreference('scalable_title','-1'),$this->GetPreference('scalable_title','-1')));
 
+$smarty->assign('title_robots_title',$this->Lang('robots_title'));
+$smarty->assign('input_robots_title',$this->CreateInputDropdown($id,'robots_title',$robotsDrop,$this->GetPreference('robots_title','-1'),$this->GetPreference('robots_title','-1')));
+
 $smarty->assign('title_publisher_title',$this->Lang('publisher_title'));
 $smarty->assign('input_publisher_title',$this->CreateInputText($id,'publisher_title',$this->GetPreference('publisher_title',''),50,255));
 
@@ -167,9 +210,18 @@ $smarty->assign('input_longitude_title',$this->CreateInputText($id,'longitude_ti
 $smarty->assign('title_ogtype_title',$this->Lang('ogtype_title'));
 $smarty->assign('input_ogtype_title',$this->CreateInputText($id,'ogtype_title',$this->GetPreference('ogtype_title','website'),50,255));
 
+$smarty->assign('title_ogtype_smarty_title',$this->Lang('ogtype_smarty_title'));
+$smarty->assign('input_ogtype_smarty_title',$this->CreateInputText($id,'ogtype_smarty_title',$this->GetPreference('ogtype_smarty_title',''),50,255));
+
 $smarty->assign('title_ogimage_title',$this->Lang('ogimage_title'));
 $smarty->assign('input_ogimage_title',$this->CreateInputDropdown($id,'ogimage_title',$files_list,-1,$this->GetPreference('ogimage_title','')));
 
+$smarty->assign('title_ogimage_smarty_title',$this->Lang('ogimage_smarty_title'));
+$smarty->assign('input_ogimage_smarty_title',$this->CreateInputText($id,'ogimage_smarty_title',$this->GetPreference('ogimage_smarty_title',''),50,255));
+
+$smarty->assign('title_favicon_root_title',$this->Lang('favicon_root_title'));
+$smarty->assign('input_favicon_root_title',$this->CreateInputDropdown($id,'favicon_root_title',$files_list_root,-1,$this->GetPreference('favicon_root_title','')));
+
 $smarty->assign('title_favicon_title',$this->Lang('favicon_title'));
 $smarty->assign('input_favicon_title',$this->CreateInputDropdown($id,'favicon_title',$files_list,-1,$this->GetPreference('favicon_title','')));
 
@@ -185,6 +237,12 @@ $smarty->assign('input_fbadmin_title',$this->CreateInputText($id,'fbadmin_title'
 $smarty->assign('title_fbapp_title',$this->Lang('fbapp_title'));
 $smarty->assign('input_fbapp_title',$this->CreateInputText($id,'fbapp_title',$this->GetPreference('fbapp_title',''),50,255));
 
+$smarty->assign('title_twittersite_title',$this->Lang('twittersite_title'));
+$smarty->assign('input_twittersite_title',$this->CreateInputText($id,'twittersite_title',$this->GetPreference('twittersite_title',''),50,255));
+
+$smarty->assign('title_googleplus_title',$this->Lang('googleplus_title'));
+$smarty->assign('input_googleplus_title',$this->CreateInputText($id,'googleplus_title',$this->GetPreference('googleplus_title',''),50,255));
+
 // Display the populated template
 echo $this->ProcessTemplate ('adminmeta.tpl');
 
