@@ -188,6 +188,8 @@ $lang['analytics_select'] = 'Please select one';
 $lang['analytics_single'] = 'A single domain';
 $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
+$lang['analytics_universal'] = 'Universal Analytics';
+$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support option will be ignored';
 $lang['analytics_support'] = 'Display Advertiser Support';
 $lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
 $lang['webmasterid_title'] = 'Webmaster meta verification key';
@@ -243,7 +245,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.3 25 February 2013. Added the option to specify canonical links per page using in content block, also added a Display Advertiser Support option to the analytics tab.</li>
 <li>Version 1.9.4 21 March 2013. Added the options to choose Apple Touch and Fav icons from the website root directory.</li>
 <li>Version 1.9.6 11 April 2013. Added the option to choose robots meta and Twitter card and Google+ profile page links.</li>
-<li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li></ul>';
+<li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li>
+<li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
